using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Text;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.Design;
using System.IO;
using System.ComponentModel.Design;



namespace CustomControlsLib
{
	[DefaultProperty("Text")]
	[ToolboxData("<{0}:RequiredTextBox runat=server></{0}:RequiredTextBox>")]
	[Designer(typeof(RequiredTextBoxDesigner),typeof(IDesigner))]
	public class RequiredTextBox : WebControl, INamingContainer
	{
		private string text;
		private string errorMessage;
		private string validatorText;
		private string validationGroup;
		private System.Drawing.Color validatorColor;

		#region Properties
		[Bindable(true)]
		[Category("Appearance")]
		[DefaultValue("")]
		public string Text
		{
			get
			{
				return text;
			}

			set
			{
				text = value;
			}
		}
		[Bindable(false)]
		[Category("Validator")]
        public string ValidatorText
		{
			get
			{
				return validatorText;
			}

			set
			{
				validatorText = value;
			}
		}
		[Bindable(false)]
		[Category("Validator")]
		public System.Drawing.Color ValidatorColor
		{
			get
			{
				return validatorColor;
			}

			set
			{
				validatorColor = value;
			}
		}
		[Bindable(false)]
		[Category("Validator")]
        public string ErrorMessage
		{
			get
			{
				return errorMessage;
			}

			set
			{
				errorMessage = value;
			}
		}
		[Bindable(false)]
		[Category("Validator")]
		public string ValidationGroup
		{
			get
			{
				return validationGroup;
			}

			set
			{
				validationGroup = value;
			}
		}
		#endregion

		public RequiredTextBox()
		{
			this.ErrorMessage = "*";
			this.ValidatorText = "*";
			this.ValidatorColor = System.Drawing.Color.Red;
		}

		protected override void CreateChildControls()
		{
			System.Web.UI.WebControls.TextBox tb;
			System.Web.UI.WebControls.RequiredFieldValidator val;

			tb = new TextBox();
			tb.ID = this.UniqueID + "_TextBox";
			tb.Text = Text;

			val = new RequiredFieldValidator();
			val.ControlToValidate = tb.ID;
			val.ErrorMessage = this.ErrorMessage;
			val.Text = this.ValidatorText;
			val.ForeColor = this.ValidatorColor;
			val.ID = this.UniqueID + "_Validator";
			val.Display = ValidatorDisplay.Dynamic;
			val.ValidationGroup = this.ValidationGroup;

			Controls.Add(tb);
			Controls.Add(new LiteralControl("&nbsp;"));
			Controls.Add(val);
		}
	}

	class RequiredTextBoxDesigner : ControlDesigner
	{
		public override string GetDesignTimeHtml()
		{
			RequiredTextBox rtb = (RequiredTextBox)Component;

			StringWriter sw = new StringWriter();
			HtmlTextWriter tw = new HtmlTextWriter(sw);

			Literal placeholder = new Literal();

			placeholder.Text = rtb.ID;
			placeholder.RenderControl(tw);

			return sw.ToString();
		}
	}
}
